@@ -1,4 +1,4 @@
-case $(uname -s) in *-WOW64) wow64=" (32-bit)" ;; esac
+case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
 /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
 /usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/GNOME-Openbox" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startx /etc/X11/xinit/Xsession openbox-gnome\"" /usr/bin/run.exe
 /usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/KDE-Openbox" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startx /etc/X11/xinit/Xsession openbox-kde\"" /usr/bin/run.exe
